//! error module.

mod http_error;
mod read_error;
pub use http_error::*;
pub use read_error::ReadError;
